pub fn report_cross_origin_denial<D>(
cx: &mut CurrentRealm<'_>,
id: Handle<'_, PropertyKey>,
access: &str,
) -> boolwhere
D: DomTypes,Expand description
Report a cross-origin denial for a property, Always returns false, so it
can be used as return report_cross_origin_denial(...);.
What this function does corresponds to the operations in
https://html.spec.whatwg.org/multipage/#the-location-interface denoted as
“Throw a SecurityError DOMException”.